@@ -6,6 +6,7 @@ import copy
 import glob
 import os
 import json
+import logging
 from Queue import Queue, Empty
 import re
 import simplenote
@@ -319,8 +320,6 @@ class NotesDB(utils.SubjectMixin):
                 
             else:
                 okey = o.key
-                # this has come back.
-                del self.threaded_syncing_keys[okey]
 
                 if o.error:
                     nerrored += 1
@@ -347,13 +346,23 @@ class NotesDB(utils.SubjectMixin):
                             # the user has changed stuff since the version that got synced
                             # just record syncnum and version that we got from simplenote
                             # if we don't do this, merging problems start happening.
-                            tkeys = ['syncnum', 'version', 'syncdate']
+                            # VERY importantly: also store the key. It
+                            # could be that we've just created the
+                            # note, but that the user continued
+                            # typing. We need to store the new server
+                            # key, else we'll keep on sending new
+                            # notes.
+                            tkeys = ['syncnum', 'version', 'syncdate', 'key']
                             for tk in tkeys:
                                 self.notes[okey][tk] = o.note[tk]
                             
                         nsynced += 1
                         self.notify_observers('change:note-status', utils.KeyValueObject(what='syncdate',key=okey))
                     
+                # after having handled the note that just came back,
+                # we can take it from this blocker dict
+                del self.threaded_syncing_keys[okey]
+
         return (nsynced, nerrored)
     
     
@@ -416,6 +425,8 @@ class NotesDB(utils.SubjectMixin):
         for ni,n in enumerate(nl):
             k = n.get('key')
             server_keys[k] = True
+            # this works, only because in phase 1 we rewrite local keys to
+            # server keys when we get an updated not back from the server
             if k in self.notes:
                 # we already have this
                 # check if server n has a newer syncnum than mine
@@ -484,6 +495,12 @@ class NotesDB(utils.SubjectMixin):
             
             if o.action == ACTION_SYNC_PARTIAL_TO_SERVER:
                 self.waiting_for_simplenote = True
+                if 'key' in o.note:
+                    logging.debug('Updating note %s (local key %s) to server.' % (o.note['key'], o.key))
+
+                else:
+                    logging.debug('Sending new note (local key %s) to server.' % (o.key,))
+                    
                 uret = self.simplenote.update_note(o.note)
                 self.waiting_for_simplenote = False
                 
@@ -496,6 +513,8 @@ class NotesDB(utils.SubjectMixin):
                         # delete our own copy too.
                         del o.note['content']
                         
+                    logging.debug('Server replies with updated note ' + n['key'])
+                        
                     # syncdate was set when the note was copied into our queue
                     # we rely on that to determine when a returned note should
                     # overwrite a note in the main list.
@@ -513,4 +532,4 @@ class NotesDB(utils.SubjectMixin):
                 else:
                     o.error = 1
                     self.q_sync_res.put(o)
-                    
\ No newline at end of file
+                    
