@@ -32,6 +32,8 @@
 
 import codecs
 import ConfigParser
+import logging
+from logging.handlers import RotatingFileHandler
 from notes_db import NotesDB, SyncError
 import os
 import sys
@@ -57,6 +59,10 @@ else:
     HAVE_DOCUTILS = True
 
 class Config:
+    """
+    @ivar files_read: list of config files that were parsed.
+    @ivar ok: True if config files had a default section, False otherwise.
+    """
     def __init__(self, app_dir):
         """
         @param app_dir: the directory containing nvPY.py
@@ -73,25 +79,43 @@ class Config:
                     'sort_mode' : '1',
                     'db_path' : os.path.join(home, '.nvpy'),
                     'font_family' : 'Courier',
-                    'font_size' : '12'
+                    'font_size' : '12',
+                    'sn_username' : '',
+                    'sn_password' : ''
                    }
         
-        # allow_no_value=True means we'll just get None for undefined values
-        cp = ConfigParser.SafeConfigParser(defaults, allow_no_value=True)
+        cp = ConfigParser.SafeConfigParser(defaults)
         # later config files overwrite earlier files
-        cp.read([os.path.join(app_dir, 'nvpy.cfg'), os.path.join(home, 'nvpy.cfg'), os.path.join(home, '.nvpy.cfg')])
+        # try a number of alternatives
+        self.files_read = cp.read([os.path.join(app_dir, 'nvpy.cfg'), 
+                                   os.path.join(home, 'nvpy.cfg'), 
+                                   os.path.join(home, '.nvpy.cfg'),
+                                   os.path.join(home, '.nvpy'),
+                                   os.path.join(home, '.nvpyrc')])
         
-        self.sn_username = cp.get('default', 'sn_username')
-        self.sn_password = cp.get('default', 'sn_password')
+        cfg_sec = 'nvpy'
+        
+        if not cp.has_section(cfg_sec):
+            cp.add_section(cfg_sec)
+            self.ok = False
+            
+        else:
+            self.ok = True
+
+        # for the username and password, we don't want interpolation,
+        # hence the raw parameter. Fixes
+        # https://github.com/cpbotha/nvpy/issues/9
+        self.sn_username = cp.get(cfg_sec, 'sn_username', raw=True)
+        self.sn_password = cp.get(cfg_sec, 'sn_password', raw=True)
         # make logic to find in $HOME if not set
-        self.db_path = cp.get('default', 'db_path')
+        self.db_path = cp.get(cfg_sec, 'db_path')
         #  0 = alpha sort, 1 = last modified first
-        self.sort_mode = cp.getint('default', 'sort_mode')
-        self.housekeeping_interval = cp.getint('default', 'housekeeping_interval')
+        self.sort_mode = cp.getint(cfg_sec, 'sort_mode')
+        self.housekeeping_interval = cp.getint(cfg_sec, 'housekeeping_interval')
         self.housekeeping_interval_ms = self.housekeeping_interval * 1000
         
-        self.font_family = cp.get('default', 'font_family')
-        self.font_size = cp.getint('default', 'font_size')
+        self.font_family = cp.get(cfg_sec, 'font_family')
+        self.font_size = cp.getint(cfg_sec, 'font_size')
         
 class NotesListModel(SubjectMixin):
     """
@@ -139,7 +163,28 @@ class Controller:
         # should probably also look in $HOME
         self.config = Config(self.appdir)
         self.config.app_version = self.get_version()
+
+        # configure logging module
+        #############################
+
+        # first create db directory if it doesn't exist yet.
+        if not os.path.exists(self.config.db_path):
+            os.mkdir(self.config.db_path)
+
+        log_filename = os.path.join(self.config.db_path, 'nvpy.log')
+        # file will get nuked when it reaches 100kB
+        lhandler = RotatingFileHandler(log_filename, maxBytes=100000)
+        lhandler.setLevel(logging.DEBUG)
+        lhandler.setFormatter(logging.Formatter(fmt='%(asctime)s - %(levelname)s - %(message)s'))
+        # we get the root logger and configure it
+        logger = logging.getLogger()
+        logger.setLevel(logging.DEBUG)
+        logger.addHandler(lhandler)
+        # this will go to the root logger
+        logging.debug('nvpy logging initialized')
         
+        logging.debug('config read from %s' % (str(self.config.files_read),))
+                
         # read our database of notes into memory
         # and sync with simplenote.
         c = self.config
@@ -192,9 +237,19 @@ class Controller:
             return None
                 
     def get_version(self):
-        return "0.8"
+        return "0.8.5"
     
     def main_loop(self):
+        if not self.config.files_read:
+            self.view.show_warning('No config file', 
+                                  'Could not read any configuration files. See https://github.com/cpbotha/nvpy for details.')
+
+        elif not self.config.ok:
+            wmsg = ('Please rename [default] to [nvpy] in %s. ' + \
+                    'Config file format changed after nvPY 0.8.') % \
+            (str(self.config.files_read),)
+            self.view.show_warning('Rename config section', wmsg)
+            
         self.view.main_loop()
         
     def observer_notes_db_change_note_status(self, notes_db, evt_type, evt):
@@ -203,7 +258,7 @@ class Controller:
             self.view.set_note_status(self.notes_db.get_note_status(skey))
             
     def observer_notes_db_sync_full(self, notes_db, evt_type, evt):
-        print evt.msg
+	logging.debug(evt.msg)
         self.view.set_status_text(evt.msg)
         
     def observer_notes_db_synced_note(self, notes_db, evt_type, evt):
